pub struct Close<'a> {
pub variant: u8,
pub name: &'a str,
}Expand description
Identifies the message as a Close command
Fields
variant: u8‘S’ to close a prepared statement; or ‘P’ to close a portal.
name: &'a strThe name of the prepared statement or portal to close (an empty string selects the unnamed prepared statement or portal).